import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defense Evasion'
        self.tid = 'T1085'
        self.name = 'Rundll32'
        self.description = '''Executes a binary using rundll32.exe'''

    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line .*rundll32(\.exe)?\s.+\,', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Credential Access'
        self.tid = 'T1110'
        self.name = 'Brute Force'
        self.description = '''Use brute force techniques to attempt access to accounts when
                        passwords are unknown or when password hashes are obtained.'''
        
    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'malware':
                if re.search('.*\_BRUTEFORCE\_', entry['name']):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False 


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Credential Access'
        self.tid = 'T1214'
        self.name = 'Credentials in Registry'
        self.description = '''Queries the registry for credentials and passwords.'''
        
    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line.+(reg.+query.+(HKLM|HKCU).+\/f.+password.+\/t.+REG_SZ.+\/s|Get\-UnattendedInstallFile|Get\-Webconfig|Get\-ApplicationHost|Get\-SiteListPassword|Get\-CachedGPPPassword|Get\-RegistryAutoLogon)', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Persistence'
        self.tid = 'T1108'
        self.name = 'Redundant Access'
        self.description = '''Use more than one remote access tool with varying command
                            and control protocols or credentialed access to remote 
                            services so they can maintain access if an access mechanism 
                            is detected or mitigated.'''
                            
    def run_rules(self, bundles):
        cnt = 0
        redundant_score = 0
        for entry in bundles['objects']:
            if entry['type'] == 'malware':
                if re.search('.*\_WEBSHELL\_', entry['name']) and redundant_score == 0:
                    redundant_score += 1
                    continue
                elif re.search('.*\_WEBSHELL\_', entry['name']) and redundant_score >= 1:     
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Exfiltration'
        self.tid = 'T1002'
        self.name = 'Data Compressed'
        self.description = '''Compress data that is collected prior to exfiltration in order to make it portable and minimize the amount of data sent over the network.'''
        
    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line .*(powershell(\.exe)? .*(-Recursive|Compress-Archive)|(rar|7z|7za)(\.exe)? .*a .*)', entry['pattern']):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Exfiltration'
        self.tid = 'T1070'
        self.name = 'Indicator Removal on Host'
        self.description = '''Adversaries may delete or alter generated artifacts on a host system.'''
        
    def run_rules(self, bundles):
        wevtutil_ptn = [
            r".*wevtutil?.+ cl system",
            r".*wevtutil?.+ cl application",
            r".*wevtutil?.+ cl security"
        ]
        indicator_ptn = "|".join(wevtutil_ptn)
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line .*'+ indicator_ptn, entry['pattern']):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False


import pkgutil
import importlib
import mitre_stix.rules as rules

def import_package(package):
    modules = []
    prefix = package.__name__ + "."
    for loader, name, ispkg in pkgutil.iter_modules(package.__path__, prefix):
        if ispkg:
            continue
        modules.append(importlib.import_module(name))
    return modules

def logs(bundles):
    signatures = import_package(rules)
    hits = []
    for sig in signatures:
        scan = sig.mitre_rules()
        result = scan.run_rules(bundles)
        if result is not False:
            hits.append({'tactic': result.tactic, 'tid': result.tid, 'name':  result.name, \
                        'description': result.description, 'oid': result.oid})
    return hits


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defense Evasion'
        self.tid = 'T1102'
        self.name = 'Web Service'
        self.description = '''Uses an existing, legitimate external web service as a means for relaying commands to a compromised system.'''
        
    def run_rules(self, bundles):
        web_services = [
            "amazon",
            "wordpress",
            "twitter",
            "dropbox",
            "github",
            "tumblr",
            "blogspot",
            "pastebin",
            "evernote",
            "yandex",
            "mediafire",
            "pcloud"
        ]
        indicator_ptn = "|".join(web_services)
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('url:extensions\.domain \= \'.*'+ indicator_ptn, entry['pattern']):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Initial Access'
        self.tid = 'T1190'
        self.name = 'Exploit Public-Facing Application'
        self.description = 'The use of software, data, or commands to take advantage of a weakness in an '+\
                            'Internet-facing computer system or program in order to cause unintended or '+\
                            'unanticipated behavior. The weakness in the system can be a bug, a glitch, '+\
                            'or a design vulnerability. These applications are often websites, '+\
                            'but can include databases (like SQL), standard services (like SMB or SSH), '+\
                            'and any other applications with Internet accessible open sockets, such as web '+\
                            'servers and related services. Depending on the flaw being exploited this may '+\
                            'include Exploitation for Defense Evasion.'

    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'malware':
                if re.search('.*SMB\_.*EXPLOIT', entry['name']):
                    o_id = entry['id']
                    for o in bundles['objects']:
                        if o['type'] == 'relationship':
                            if o['source_ref'] == o_id and o['relationship_type'] == 'target':
                                s_id = o['target_ref']
##                                print s_id
                                break
                    else:
                        s_id = False
                    if s_id != False:
                        for o_r in bundles['objects']:
                            if o_r['type'] == 'identity':
                                if o_r['id'] == s_id:
                                    if re.search('(172\.([1][6-9]|2[0-9]|3[0-1])|10\.[0-9]+|192\.168)\.[0-9]+\.[0-9]+', o_r['name']):
                                        i = False
                                    else:
                                        self.oid.append(o_id)
                                        cnt += 1
                                    break
                                
##                        if i is True:
##                            for o_r in bundles['objects']:
##                                if o_r['type'] == 'relationship':
##                                    if o_r['source_ref'] == s_id:
##                                        t_id = o_r['target_ref']
##    ##                                    print t_id
##                                        break
##                            else:
##                                t_id = False
##                            if t_id != False:
##                                for o_r in bundles['objects']:
##                                    if o_r['id'] == t_id:
##                                        if o_r['type'] == 'indicator':
##                                            self.oid.append(o_id)
##                                            cnt += 1
##                                            break
                                

        if cnt != 0:
            return self
        else:
            return False
                            

            



import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defense Evasion'
        self.tid = 'T1089'
        self.name = 'Disabling Security Tools'
        self.description = '''Disable security tools to avoid possible detection of their tools and activities.'''
        
    def run_rules(self, bundles):
        cnt = 0
        tool_list = ["@AAWTray","_avp32","_avpcc","_avpm","a2cmd","a2guard","a2service","a2start","a2wizard","AAV_Guard","AAV_Service_Vista","aAvgApi","abmainsv","ackwin32","acs","Ad-Aware","adaware","AdAwareDesktop","AdAwareService","AdAwareTray","AdvancedSystemProtector","advxdwin","afwServ","AgentSvc","agentsvr","agentw","alertsvc","alevir","ALMon","alogserv","ALsvc","amon9x","anti-trojan","antivirservice","antivirus","ants","apimonitor","aplica32","apvxdwin","arr","ARWSRVC","ASCService","ASDSvc","ASDUp","ashDisp","ashQuick","ashUpd","aswChLic","aswidsagenta","aswmbr","aswOfferTool","aswWrcIELoader32","aswWrcIELoader64","atcon","atguard","atro55en","atupdater","atwatch","au","aupdate","auto-protect.nav80try","AutoCare","autodown","autotrace","autoupdate","av_task","avast_free_antivirus_setup_online","AvastNM","AvastPE2","AvastSvc","AvastUI","avcom","avconfig","avconsol","ave32","AvEmUpdate","aveservice","avgcc32","avgcsrvx","avgctrl","avgemc","avgidsagent","avgnt","avgrsx","avgserv","avgserv9","AVGSvc","avguard","avgw","avgwdsvc","Avira.ServiceHost","AVK","avkpop","avkproxy","avkserv","avkservice","AVKTray","avkwctl9","AVKWCtlx64","AvLaunch","avltmain","avnt","avp","avp32","avpcc","avpdos32","avpm","avpmapp","avptc32","avpupd","avscan","AVScanningService","avsched32","avss","avsynmgr","AVWatchService","avwin","avwin95","avwinnt","avwupd","avwupd32","avwupsrv","avxmonitor9x","avxmonitornt","avxquar","axengine","backweb","bargains","Bav","bavhm","BavSvc","BavTray","BavUpdater","BavWebClient","bd_professional","bdagent","bdservicehost","BDSSVC","beagle","belt","BgScan","bidef","bidserver","bipcp","bipcpevalsetup","bisp","blackd","blackice","blink","blinksvc","blss","bootconf","bootwarn","borg2","bpc","bs120","BullGuard","BullGuardBhvScanner","BullGuardCore","BullGuardUpdate","BullGuarScanner","bvt","callmsi","capinfos","catchme","cavwp","ccapp","ccavsrv","ccevtmgr","ccpxysvc","ccSvcHst","cdp","CertReg","cfd","cfgwiz","cfiadmin","cfiaudit","cfinet","cfinet32","cfp","cis","CisTray","clamav","clamscan","ClamTray","ClamWin","claw95","claw95cf","cleaner","cleaner3","cleanpc","click","cmcark","cmdagent","cmesys","cmgrdian","cmon016","ComboFix","CommService","ConfigSecurityPolicy","connectionmonitor","CONSCTLX","coreFrameworkHost","coreServiceShell","cpd","cpf9x206","cpfnt206","ctrl","cv","cwnb181","cwntdwmo","datemanager","dcomx","defalert","defscangui","defwatch","deputy","divx","dllcache","dllreg","doors","dpf","dpfsetup","dpps2","dragon_updater","drwatson","drweb32","drwebupw","dssagent","dumpcap","dvp95","dvp95_0","dwservice","eCapture","ecengine","ecls","ecmd","ecmds","eComServer","econceal","econser","editcap","eeclnt","EEYEEVNT","efpeadm","egui","ekrn","EmDmp","EMLPROXY","EmsiClean","EmsisoftAntiMalwareSetup","emsw","ent","eOPPFrame","esafe","escanhnt","escanmon","escanpro","escanv95","espwatch","ethereal","etrustcipe","evpn","exantivirus-cnet","exe.avxw","expert","explore","f-agnt95","f-prot","f-prot95","f-stopw","fameh32","fast","fcappdb","FCDBlog","fch32","FCHelper64","fih32","FilMsg","FilUp","filwscc","findviru","flister","fmon","fnrb32","FortiClient","FortiClient_Diagnostic_Tool","FortiESNAC","FortiFW","FortiProxy","FortiSettings","FortiSSLVPNdaemon","FortiTray","fp-win","fp-win_trial","fpavserver","fprot","FProtTray","FPWin","freshclam","freshclamwrap","frw","fsaa","fsav","fsav32","fsav530stbyb","fsav530wtbyb","fsav95","fsgk32","fsguiexe","FSHDLL64","fshoster","fshoster32","fshoster64","fsm32","fsma","fsma32","fsmb32","fsorsp","fssm32","fsulprothoster","gator","gbmenu","gbpoll","GdBgInx64","GDFwSvcx","GDKBFltExe32","GDSC","GDScan","generics","gmt","grizzlyav","grizzlysvc","gsam","guard","guarddog","guardxkickoff","guardxkickoff_64","guardxkickoff_x64","guardxservice","guardxservice_x64","hacktracersetup","hbinst","hbsrv","hijackthis","HookShark","hotactio","hotpatch","htlog","htpatch","hwpe","hxdl","hxiul","iamapp","iamserv","iamstats","ibmasn","ibmavsp","icload95","icloadnt","icmon","icsupp95","icsuppnt","idle","iedll","iedriver","iface","ifw2000","ikarus-guardx","immunetprotect","inetlnfo","infus","infwin","init","instup","intdel","intren","iomon98","iptray","istsvc","jammer","jdbgmrg","jedi","K7AVScan","K7CrvSvc","K7EmlPxy","K7FWSrvc","K7PSSrvc","K7RTScan","K7SysMon","K7TSecurity","K7TSMain","K7TSMngr","kavlite40eng","kavpers40eng","kavpf","kazza","keenvalue","kerio-pf-213-en-win","kerio-wrl-421-en-win","kerio-wrp-421-en-win","kernel32","killprocesssetup161","ldnetmon","ldpro","ldpromenu","ldscan","LittleHook","lnetinfo","localnet","lockdown","lockdown2000","lookout","lordpe","lsetup","luall","luau","lucomserver","luinit","luspt","malwarebytes_assistant","mapisvc32","mbam","mbamgui","MbamPt","mbamscheduler","MBAMService","mbamtray","MBAMWsc","mbr","mcagent","McCSPServiceHost","mcmnhdlr","MCS-Uninstall","McsAgent","mcshield","MCShieldCCC","MCShieldDS","MCShieldRTM","mctool","McUICnt","mcupdate","mcvsrte","mcvsshld","md","mergecap","MFEConsole","mfin32","mfw2en","mfweng3.02d30","mgavrtcl","mgavrte","mghtml","mgui","minilog","mmod","ModuleCoreService","monitor","moolive","mostat","MpCmdRun","mpfagent","mpfservice","mpftray","MpUXSrv","mrflux","msapp","MSASCui","msbb","msblast","mscache","msccn32","mscman","msdm","msdos","msgui","msiexec16","msinfo32","mskrn","mslaugh","msmgt","MsMpEng","msmpsvc","msmsgri32","msseces","mssmmc32","mssys","msvxd","mu0311ad","MWAGENT","MWASER","mwatch","n32scanw","nanoav","nanoav64","nanosvc","nav","navap.navapsvc","navapsvc","navapw32","navdx","navlu32","navnt","navstub","navw32","navwnt","nbrowser","nc2000","ncinst4","ndd32","neomonitor","neowatchlog","netarmor","netd32","netinfo","netmon","netscanpro","netspyhunter-1.2","netstat","netutils","nfservice","nisserv","NisSrv","nisum","njeeves2","nmain","nnf","nod32","normist","norton_internet_secu_3.0_407","NortonAntiBot","nortonsecurity","notstart","npf40_tw_98_nt_me_2k","npfmessenger","nprosec","nprotect","npscheck","npssvc","NS","nsched32","nseupdatesvc","nssys32","nstask32","nsupdate","nt","ntrtscan","ntvdm","ntxconfig","nui","nupgrade","nvarch16","nvc95","nvcod","nvcsvc","nvoy","nvsvc32","nwinst4","nwscmon","nwservice","nwtool16","ollydbg","ONLINENT","onsrvr","op_mon","OPSSVC","optimize","ostronet","otfix","outpost","outpostinstall","outpostproinstall","padmin","panixk","patch","Pavark","pavcl","pavproxy","pavsched","pavsrv","pavw","pccwin98","pcfwallicon","pcip10117_0","PCKAVService","pcscan","pdsetup","periscope","persfw","perswf","pf2","pfwadmin","pgmonitr","pingscan","platin","pop3trap","poproxy","popscan","portdetective","portmonitor","powerscan","ppinupdt","pptbc","ppvstop","prizesurfer","prmt","prmvr","procdump","processhacker-2.39-setup","ProcessHacker","processmonitor","procexp","procexplorerv1.0","programauditor","proport","protectx","PSANHost","pshost","pspf","PSUAMain","PSUAService","psview","PtSessionAgent","PtSvcHost","PtWatchDog","qconsole","QHActiveDefense","qhpisvr","QHWatchdog","QQPCRTP","QQPCTray","qserver","quamgr","QUHLPSVC","rapapp","rav7","rav7win","rav8win32eng","rawshark","rb32","rcsync","realmon","reged","RegReveal","REPRSVC","rescue","rescue32","rrguard","rshell","RsMgrSvc","RsTray","rstrui","rtvscan","rtvscn95","rulaunch","run32dll","rundll","rundll16","ruxdll32","safeweb","sahagent","SAPISSVC","SASCore64","SASTask","savenow","SAVAdminService","savservice","SBAMSvc","SBAMTray","SBPIMSvc","sbserv","scam32","scan32","scan95","SCANNER","scanpm","SCANWSCS","sched","schmgr","scproxysrv","scrscan","ScSecSvc","SDFSSvc","SDScan","SDTray","SDWelcome","serv95","setup_flowprotector_us","setupvameeval","sfc","sgssfw32","shellspyinstall","shn","showbehind","SISIPSService","smc","smss32","soap","sofi","speclean","sperm","spf","sphinx","spideragent","spoler","spoolcv","spoolsv32","spybotsd","spyxx","srexe","srng","ss3edit","ssg_4104","ssgrate","SSUpdate64","st2","stcloader","STOPzilla","SUPERAntiSpyware","SUPERDelete","supftrl","svchostc","svchosts","svshost","sweep95","sweepnet.sweepsrv.sys.swnetsup","symproxysvc","SysInspector","sysupd","SZServer","tbscan","tcm","tds-3","tds2-98","tds2-nt","teekids","text2pcap","tfak","tfak5","tgbob","titanin","titaninxp","tracert","TRAYICOS","TRAYSSER","trickler","trigger","trjscan","trjsetup","trojantrap3","tsadbot","tshark","tvmd","tvtmd","twister","twsscan","twssrv","uiSeAgnt","uiUpdateTray","uiWatchDog","uiWinMgr","undoboot","UnThreat","updat","update","upgrad","UserReg","utpost","utsvc","V3Main","V3Medic","V3Proxy","V3SP","V3Svc","V3Up","vba32ldr","vba32ldrgui","vbcmserv","vbcons","vbservprof","vbust","vbwin9x","vbwinntw","VC90Setup_P_DESKTOP_All_x64","vcsetup","vet32","vet95","vettray","vfsetup","VIEWTCP","VipreAAPSvc","VIPREUI","vir-help","ViRobot7x64_Trial","ViRobot7x86_Trial","ViRobotAPTShieldSetup_Free","virusmdpersonalfirewall","virusutilities","VisthAux","vnlan300","vnpc3000","vpc32","vpc42","vpfw30s","vptray","vscan40","vscenu6.02d30","vsched","vsecomr","vshwin32","vsisetup","vsmain","vsmon","vsstat","vswin9xe","vswinntse","vswinperse","w32dsm89","w9x","watchdog","WebCompanion","webdav","webscanx","webtrap","wfindv32","whoswatchingme","wimmun32","win-bugsfix","win32","win32us","winactive","windefend","window","windows","wininetd","wininitx","winlogin","winmain","winnet","winppr32","winrecon","winservn","winssk32","winstart","winstart001","wintsk32","winupdate","wireshark","wkufind","wnad","wnt","wradmin","wrctrl","WRSA","wsbgate","wsc_proxy","wupdater","wupdt","wyvernworksfirewall","xpf202en","ZAM","Zanda","ZAPrivacyService","zapro","zapsetup3001","zatutor","Zemana.AntiMalware.Setup","ZIS","ZISCore","zlclient","Zlh","zlhh","zonalm2601","zonealarm"]
        tool_ptn = r"({0})(\.exe)".format("|".join(tool_list))
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line .*taskkill.*\s'+tool_ptn+ r'\s.*', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
                if re.search('process:command_line .*(netsh(\.exe)?\s*advfirewall set (allprofiles|currentprofile|domainprofile|privateprofile|publicprofile) state off)|(netsh(\.exe)?\s*firewall set opmode mode=disable)', entry['pattern']):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Lateral Movement'
        self.tid = 'T1210'
        self.name = 'Exploitation of Remote Services'
        self.description = 'Exploitation of a software vulnerability occurs when ' + \
                            'an adversary takes advantage of a programming error' + \
                            'in a program, service, or within the operating system' +\
                            'software or kernel itself to execute adversary-controlled' +\
                            'code. A common goal for post-compromise exploitation of' +\
                            'remote services is for lateral movement to enable access' +\
                            'to a remote system.'

    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'malware':
                if re.search('.*SMB\_.*EXPLOIT', entry['name']):
                    o_id = entry['id']
                    for o in bundles['objects']:
                        if o['type'] == 'relationship':
                            if o['source_ref'] == o_id and o['relationship_type'] == 'target':
                                s_id = o['target_ref']
                                break
                    else:
                        s_id = False
                    if s_id != False:
                        for o_r in bundles['objects']:
                            if o_r['type'] == 'identity':
                                if o_r['id'] == s_id:
                                    if re.search('(172\.([1][6-9]|2[0-9]|3[0-1])|10\.[0-9]+|192\.168)\.[0-9]+\.[0-9]+', o_r['name']):
                                         self.oid.append(o_id)
                                         cnt += 1

        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Persistence" Movement'
        self.tid = 'T1084'
        self.name = 'Windows Management Instrumentation Event Subscription'
        self.description = '''Uses WMI to subscribe to an event and 
                                execute arbitrary code when that event occurs, 
                                providing persistence on a system'''
        
    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line .*wmic(\.exe)?\s+(\/|-)NAMESPACE:.\\\\root\\subscription.\s+PATH\s+', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
                elif re.search('process:command_line .*mofcomp(\.exe)?.*\.mof.*', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break

        if cnt != 0:
            return self
        else:
            return False 


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defense Evasion'
        self.tid = 'T1117'
        self.name = 'Regsvr32'
        self.description = '''Register and unregister object linking and embedding controls'''

    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:name\s.+\'regsvr32(\.exe)?\'', entry['pattern'], re.IGNORECASE):
                    if 'object' in entry['labels']:
                        self.oid.append(entry['id'])
                        cnt += 1
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defense Evasion'
        self.tid = 'T1216'
        self.name = 'Signed Script Proxy Execution'
        self.description = '''Scripts signed with trusted certificates can be used to proxy execution of malicious files'''

    def run_rules(self, bundles):
        proc = [ 
            r".*Windows\\System32\\.*\\pubprn\.vbs .+", 
            r".*pubprn\.vbs .+",
            r".*Windows\\System32\\SyncAppvPublishingServer\.vbs .+" 
            r".*cscript\.exe .+"
        ]
        proc_list = "|".join(proc)
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line' + proc_list, entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defense Evasion'
        self.tid = 'T1500'
        self.name = 'Compile After Delivery'
        self.description = '''Delivers files to victims as uncompiled code which will need to be compiled before execution.'''
        
    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line .*[\"\']\%Windows\%\\\\Microsoft\.NET\\\\Framework\\\\.+\\\\csc(\.exe)?', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Execution'
        self.tid = 'T1086'
        self.name = 'PowerShell'
        self.description = '''PowerShell is a powerful interactive command-line interface and 
                            scripting environment included in the Windows operating system. 
                            Adversaries can use PowerShell to perform a number of actions, 
                            including discovery of information and execution of code. Examples 
                            include the Start-Process cmdlet which can be used to run an 
                            executable and the Invoke-Command cmdlet which runs a command 
                            locally or on a remote computer.'''

    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line .+ \'(powershell\.exe)\'', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
        if cnt != 0:
            return self
        else:
            return False



import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defense Evasion'
        self.tid = 'T1202'
        self.name = 'Indirect Command Execution'
        self.description = '''Uses various Windows utilities to execute commands, possibly without invoking cmd.'''
        
    def run_rules(self, bundles):
        indirect = [r"forfiles(\.exe)? /p (:\\)+.* /m .+\..+ /c .*",
                    r"pcalua(\.exe)? -a .+\..+"]
        indicator_ptn = "|".join(indirect)
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line .*'+ indicator_ptn, entry['pattern']):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Execution'
        self.tid = 'T1064'
        self.name = 'Scripting'
        self.description = '''Use of scripts to aid operations and perform multiple instructions'''

    def run_rules(self, bundles):
        proc = [
			r'.*wscript(\.exe)?',
            r'.*cmd(\.exe)? (\/c)? .+',
			r'.*wscript(\.exe)? .+',
			r'.*powershell(\.exe)?',
			r'.*powershell(\.exe)? .+',
			r'.*cmd(\.exe)?(\')? (\/c)? .*\.bat',
			r'.*cmd(\.exe)? (\/c)?  .*\.lnk',
			r'.*cmd(\.exe)?(\')? (\/c)?  .*\.ps1',
			r'.*cmd(\.exe)? (\/c)?  .*\.vba',
			r'.*cmd(\.exe)? (\/c)?  .*\.js',
			r'.*cmd(\.exe)?(\')? (\/c)? .* -executionpolicy (bypass)?',
			r'.*cmd(\.exe)?(\')? (\/c)? .* -ep bypass .+',
			r'.*\.vbs(.*)?',
			r'.*\.js(.*)?',
			r'.*\.ps1(.*)?',
			r'.*\.bat(.*)?',
			r'.*\.lnk(.*)?',
			r'.*\.vbe(.*)?'
		]
        proc_list = '|'.join(proc)
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('(process:command_line\s|process:name\s)' + proc_list, entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Persistence'
        self.tid = 'T1100'
        self.name = 'Web Shell'
        self.description = '''A Web shell may provide a set of functions to 
                            execute or a command-line interface on the system 
                            that hosts the Web server.'''
    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'malware':
                if re.search('.*\_WEBSHELL\_', entry['name']):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Initial Access'
        self.tid = 'T1189'
        self.name = 'Drive-by Compromise'
        self.description = '''A drive-by compromise is when an adversary gains 
                            access to a system through a user visiting a 
                            website over the normal course of browsing. With 
                            this technique, the user's web browser is 
                            typically targeted for exploitation, but 
                            adversaries may also use compromised websites 
                            for non-exploitation behavior such as acquiring 
                            application access tokens.'''

    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'attack-pattern':
                if re.search('HTTP\_[a-zA-Z]+_EK', entry['name']):
                    self.oid.append(entry['id'])
                    cnt += 1
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defense Evasion'
        self.tid = 'T1218'
        self.name = 'Signed Binary Proxy Execution'
        self.description = '''Use of Microsoft Signed Binaries to execute malicious code'''

    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line .*msiexec(\.exe)?.+.*((\.msi)|(\.dll))', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
                elif re.search('process:command_line (.*mavinject(\.exe)?.+|.*SyncAppvPublishingServer(\.exe)?.+|.*odbcconf(\.exe)?.+)', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Lateral Movement'
        self.tid = 'T1105'
        self.name = 'Remote File Copy'
        self.description = '''Copies files from external sources'''
        
    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('(process:command_line .*certutil(\.exe)?\s+(?=.*-urlcache)(?=.*-split)(?=.*-f).+)', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break

            if entry['type'] == 'malware':
                if re.search('.*\_DOWNLOAD\_', entry['name']):
                    o_id = entry['id']
                    s_ref = None
                    for o in bundles['objects']:
                        if o['type'] == 'relationship':
                            if o['target_ref'] == o_id and o['relationship_type'] == 'uses':
                                s_ref = o['source_ref']
                                break
                    if s_ref:
                        for o_rto in bundles['objects']:
                            if o_rto['type'] == 'relationship':
                                if o_rto['target_ref'] == s_ref and o_rto['relationship_type'] == 'related-to':
                                    is_ref = o_rto['source_ref']
                                    for indicator in bundles['objects']:
                                        if indicator['type'] == 'indicator':
                                            if re.search('http|https', indicator['name']):
                                                self.oid.append(o_id)
                                                cnt += 1
                                                break
                                            if re.search('(172\.([1][6-9]|2[0-9]|3[0-1])|10\.[0-9]+|192\.168)\.[0-9]+\.[0-9]+', indicator['name']):
                                                cnt = 0
                                                break
                                            else:
                                                self.oid.append(o_id)
                                                cnt += 1
                                                break

        if cnt != 0:
            return self
        else:
            return False 


import setuptools

with open('README.md')as f:
    long_description = f.read()

setuptools.setup(
    name="mitre_stix",
    version="0.0.5",
    author="Henry Alarcon Jr.",
    author_email="henry_alarconjr@trendmicro.com",
    description="A Python package that scans mitre signatures from STIX2.0 json log format",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.trendmicro.com/henryal/mitre-stix",
    keywords="Cyber threat intelligence",
    packages=setuptools.find_packages(),
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Topic :: Security',
        'License :: OSI Approved :: MIT License',
    ],
    python_requires='>=3.0',
)


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Credential Access'
        self.tid = 'T1208'
        self.name = 'Kerberoasting'
        self.description = '''Attempt to acquire Kerberos tickets'''

    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line.+(setspn\s+-T\s.+-Q\s+\*\/\*|servicePrincipalName|Where\s+\{\^\$_.servicePrincipalName}|KerberosRequestorSecurityToken|Invoke-Kerberoast)\s', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defensive Evasion'
        self.tid = 'T1191'
        self.name = 'CMSTP'
        self.description = '''Uses cmstp.exe to execute malicious script to evade detection'''

    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('(process:command_line\s.*cmstp(\.exe)?\s.+|process:name\s.+\'cmstp\.exe\')', entry['pattern'], re.IGNORECASE):
                    if re.search('process:command_line\s.+cmstp(\.exe)?\s\/s', entry['pattern'], re.IGNORECASE):
                        self.oid.append(entry['id'])
                        cnt += 1
        if cnt != 0:
            return self
        else:
            return False


import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defense Evasion'
        self.tid = 'T1003'
        self.name = 'Credential Dumping'
        self.description = '''Obtaining sensitive login information of users normally 
                            in the form of a hash or a clear text password, from the 
                            operating system and software.'''
        
    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('(process:name.+\'reg.exe\'.+process:command_line.+(save.+HKLM\\\\sam.+|save.+HKLM\\\\system.+)|process:command_line.+(Invoke\s\-Mimikatz\s\-DumpCreds|gsecdump\s\-a|wce\s\-o|procdump\s\-ma\slsass(\.exe)?|ntdsutil.+ac\si\sntds.+ifm.+create full))', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False